Enum QueueSet3Selected
Source pub enum QueueSet3Selected<T0, T1, T2> {
Q0(T0),
Q1(T1),
Q2(T2),
}
Indicates which queue in the set was selected and carries the
received item.
An item was received from the corresponding queue.
An item was received from the corresponding queue.
An item was received from the corresponding queue.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.